LogNormalization class

Logarithmic normalization: log(value + 1) / scale, clamped to 0, 1.

Inheritance

Constructors

LogNormalization({double scale = 5.0})
const
LogNormalization.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scale double
Scale factor for the log value.
final

Methods

normalize(double value) double
Normalize a raw value.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited