ProfileQueryCriteria class

Criteria for querying profile history.

Constructors

ProfileQueryCriteria({String? profileId, String? profileVersion, String? contextId, DateTimeRange? timeRange, ProfileRunStatus? status, double? minScore, double? maxScore, String sortBy = 'startedAt', bool ascending = false, int limit = 100, int offset = 0})
const

Properties

ascending bool
Sort direction.
final
contextId String?
Filter by context ID.
final
hashCode int
The hash code for this object.
no setterinherited
limit int
Maximum results.
final
maxScore double?
Filter by maximum aggregated score.
final
minScore double?
Filter by minimum aggregated score.
final
offset int
Offset for pagination.
final
profileId String?
Filter by profile ID.
final
profileVersion String?
Filter by profile version.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sortBy String
Sort field.
final
status ProfileRunStatus?
Filter by run status.
final
timeRange DateTimeRange?
Filter by time range.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited