VersionConstraintException class

Exception thrown when no version matches a constraint.

Implemented types

Constructors

VersionConstraintException({required VersionConstraint constraint, required List<String> availableVersions})
const

Properties

availableVersions List<String>
Available versions that were checked.
final
constraint VersionConstraint
The constraint that could not be satisfied.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited