AppraisalEnginePort class abstract
Engine contract for appraisal metric computation.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
computeAggregate(
Map< String, MetricComputeResult> metrics, AggregationConfig? config) → Future<double> - Reduce compute results into a single aggregated score.
-
computeMetrics(
List< AppraisalMetricDef> metrics, RuntimeProfileContext context) → Future<Map< String, MetricComputeResult> > - Compute metrics based on definitions and context.
-
getHistory(
String profileId, Period period) → Future< List< AppraisalResult> > - Historical appraisal results.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited