MetricTrendAnalysis class
Analysis of metric trends over time.
Constructors
-
MetricTrendAnalysis({required String metricId, required List<
double> values, required double mean, required double stddev, required TrendDirection trend}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- mean → double
-
Mean value.
final
- metricId → String
-
Metric identifier.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stddev → double
-
Standard deviation.
final
- trend → TrendDirection
-
Trend direction: positive (increasing), negative (decreasing), flat.
final
-
values
→ List<
double> -
Metric values over time.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited