StubProfileQueryPort class
Stub implementation for testing.
- Implemented types
Constructors
- StubProfileQueryPort()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
analyzeMetricTrends(
{required String profileId, required String metricId, required DateTimeRange timeRange}) → Future< MetricTrendAnalysis> -
Analyze metric trends over time.
override
-
findProfilesFromPattern(
{required String patternId, DateTimeRange? timeRange, int limit = 10}) → Future< List< ProfileRun> > -
Find profiles associated with a pattern.
override
-
findSimilarApplications(
{required String profileId, required double minScoreSimilarity, DateTimeRange? timeRange, int limit = 10}) → Future< List< ProfileRun> > -
Find similar profile applications.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryProfileRuns(
ProfileQueryCriteria criteria) → Future< List< ProfileRun> > -
Query profile runs matching criteria.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited